mailr10717 - /1.3/test_suite/unit_tests/_auto_analyses/test___init__.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on February 18, 2010 - 13:39:
Author: bugman
Date: Thu Feb 18 13:39:02 2010
New Revision: 10717

URL: http://svn.gna.org/viewcvs/relax?rev=10717&view=rev
Log:
Modified the _auto_analyses.test___init__ module for the auto_analyses 
package.


Modified:
    1.3/test_suite/unit_tests/_auto_analyses/test___init__.py

Modified: 1.3/test_suite/unit_tests/_auto_analyses/test___init__.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_auto_analyses/test___init__.py?rev=10717&r1=10716&r2=10717&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_auto_analyses/test___init__.py (original)
+++ 1.3/test_suite/unit_tests/_auto_analyses/test___init__.py Thu Feb 18 
13:39:02 2010
@@ -1,6 +1,6 @@
 
###############################################################################
 #                                                                            
 #
-# Copyright (C) 2009 Edward d'Auvergne                                       
 #
+# Copyright (C) 2009-2010 Edward d'Auvergne                                  
 #
 #                                                                            
 #
 # This file is part of the program relax.                                    
 #
 #                                                                            
 #
@@ -26,15 +26,15 @@
 
 # relax module imports.
 from test_suite.unit_tests.package_checking import PackageTestCase
-import specific_fns
+import auto_analyses
 
 
 class Test___init__(PackageTestCase):
     """Unit tests for the specific_fns package."""
 
     def setUp(self):
         """Set up for the package checking."""
 
-        self.package = specific_fns
-        self.package_name = 'specific_fns'
-        self.package_path = sys.path[0] + sep + 'specific_fns'
+        self.package = auto_analyses
+        self.package_name = 'auto_analyses'
+        self.package_path = sys.path[0] + sep + 'auto_analyses'
@@ -26,15 +26,15 @@
 
 class Test___init__(PackageTestCase):
-    """Unit tests for the specific_fns package."""
+    """Unit tests for the auto_analyses package."""
 
     def setUp(self):




Related Messages


Powered by MHonArc, Updated Thu Feb 18 14:00:02 2010